/* SingIt Lyrics Displayer
 * Copyright (C) 2000, 2001 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef __SINGIT_MACROS_H__
#define __SINGIT_MACROS_H__

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <singit_config.h>

#ifdef ENABLE_NLS
#  include <locale.h>
#    include <libintl.h>
#    define _(String) gettext (String)
#    ifdef gettext_noop
#        define N_(String) gettext_noop (String)
#    else
#        define N_(String) (String)
#    endif
#else
/* Stubs that do something close enough.  */
#    define textdomain(String) (String)
#    define gettext(String) (String)
#    define dgettext(Domain,Message) (Message)
#    define dcgettext(Domain,Message,Type) (Message)
#    define bindtextdomain(Domain,Directory) (Domain)
#    define _(String) (String)
#    define N_(String) (String)
#endif

#ifdef __GNUC__
/* enable -Wformat with debug() */
void debug(char *format, ...) __attribute__ ((format (printf, 1, 2)));
#else
void debug(char *format, ...);
#endif

inline SingitConfig *get_singit_config(void);

#define DEBUG(x)  { if (get_singit_config() && get_singit_config()->enableDebug) debug x; }
#define PERROR(x) { if (get_singit_config() && get_singit_config()->enableDebug) perror(x); }

#ifdef HAVE_ID3
void singit_id3_show();
#endif

#define SINGIT_VERSION_STRING "XMMS SingIt v" VERSION
#define SINGIT_MAX_PATH_SIZE 1024
#define JMG_EMAIL "glogow@stud.fbi.fh-darmstadt.de"

#endif  // __SINGIT_MACROS_H__
